#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bz2
version:              1.0.1.1
visibility:           public
id:                   bz2-1.0.1.1-8L0pXUboX5ZJ6L2nZNYiUr
key:                  bz2-1.0.1.1-8L0pXUboX5ZJ6L2nZNYiUr
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  1143feed47c78d52109a2f2502f82540
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Common Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Unpack Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.1-8L0pXUboX5ZJ6L2nZNYiUr
extra-libraries:      bz2
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

